@@ -19,6 +19,9 @@
  *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#ifndef __PBARS_H__
+#define __PBARS_H__
+
 #include <gtk/gtk.h>
 
 void create_pbar_type1(const gchar* title);
@@ -31,3 +34,5 @@ void create_pbar(int type, const gchar * title);
 void destroy_pbar(void);
 
 void on_pbar_okbutton1_pressed(GtkButton* button, gpointer user_data);
+
+#endif
