@@ -29,6 +29,7 @@
 
 #include "gstruct.h"
 #include "tilp_core.h"
+#include "tilp.h"
 #include "dboxes.h"
 #include "pbars.h"
 #include "about.h"
@@ -45,6 +46,7 @@
 #include "action.h"
 #include "gtk_update.h"
 #include "screenshot.h"
+#include "bookmark.h"
 
 #ifdef __WIN32__
 #define strcasecmp _stricmp
@@ -77,7 +79,7 @@ void show_right_view(int view)
 	}
 }
 
-GtkWidget *display_tilp_dbox()
+GtkWidget *display_tilp_dbox(void)
 {
 	GtkWidget *dbox;
 	GtkWidget *paned;
@@ -162,8 +164,6 @@ TILP_EXPORT gboolean on_tilp_dbox_delete_event(GtkWidget* widget, GdkEvent* even
 
 /* Help menu */
 
-extern int go_to_bookmark(const char *link);
-
 TILP_EXPORT void on_manual1_activate(GtkMenuItem* menuitem, gpointer user_data)
 {
 	gchar *path = g_strconcat(inst_paths.help_dir, _("Manual_en.html"), NULL);
@@ -261,7 +261,7 @@ TILP_EXPORT void on_rom_dump1_activate(GtkMenuItem* menuitem, gpointer user_data
 		dst_filename2 = g_strconcat(dst_filename, ".", "rom", NULL);
 	else
 		dst_filename2 = g_strdup(dst_filename);
-	g_free((void *)dst_filename);
+	//g_free((void *)dst_filename);
 
 	if (dst_filename2)
 	{
@@ -318,7 +318,7 @@ TILP_EXPORT void on_tilp_button3b_clicked(GtkButton* button, gpointer user_data)
 		dst_filename2 = g_strconcat(dst_filename, ".", tifiles_fext_of_backup(options.calc_model), NULL);
 	else
 		dst_filename2 = g_strdup(dst_filename);
-	g_free((void *)dst_filename);
+	//g_free((void *)dst_filename);
 
 	if (dst_filename2)
 	{
@@ -332,8 +332,6 @@ TILP_EXPORT void on_tilp_button3b_clicked(GtkButton* button, gpointer user_data)
 	labels_refresh();
 }
 
-TILP_EXPORT void on_tilp_button7_clicked(GtkButton* button, gpointer user_data);
-
 TILP_EXPORT void on_tilp_button3_clicked(GtkButton* button, gpointer user_data)
 {
 	if(options.backup_as_tigroup && tifiles_is_flash(options.calc_model))
@@ -365,8 +363,6 @@ TILP_EXPORT void on_tilp_button4_clicked(GtkButton* button, gpointer user_data)
 		else if(tifiles_file_is_backup(filename))
 			tilp_calc_send_backup(filename);
 	}
-
-	return;
 }
 
 static int save_group(void)
@@ -393,7 +389,7 @@ static int save_group(void)
 		dst_filename2 = g_strconcat(dst_filename, ".", tifiles_fext_of_group(options.calc_model), NULL);
 	else
 		dst_filename2 = g_strdup(dst_filename);
-	g_free((void *)dst_filename);
+	//g_free((void *)dst_filename);
 
 	if (dst_filename2)
 	{
@@ -468,7 +464,7 @@ void on_tilp_send(const gchar *user_data)
 		f = (FileEntry *) local.selection3->data;
 
 		// send os upgrades
-		if(tifiles_file_is_flash(f->name) || tifiles_file_is_tigroup(f->name)) 
+		if(tifiles_file_is_flash(f->name))
 		{
 			if(tifiles_file_test(f->name, TIFILE_OS, options.calc_model))
 			{
@@ -477,6 +473,7 @@ void on_tilp_send(const gchar *user_data)
 			} 
 			else if(tifiles_file_is_app(f->name))
 			{
+do_app:
 				ret1 = tilp_calc_send_app();
 				if(!ret1)
 				{
@@ -486,7 +483,11 @@ void on_tilp_send(const gchar *user_data)
 					labels_refresh();
 				}
 			}
-		} 
+		}
+		else if (tifiles_file_is_tigroup(f->name))
+		{
+			goto do_app;
+		}
 	}
 
 	// send vars
@@ -555,7 +556,7 @@ TILP_EXPORT void on_tilp_button6_clicked(GtkButton* button, gpointer user_data)
 	tilp_local_selection_destroy();
 }
 
-// Recv TiGroup
+// Recv TIGroup
 TILP_EXPORT void on_tilp_button7_clicked(GtkButton* button, gpointer user_data)
 {
 	char* src_filename;
@@ -584,7 +585,7 @@ TILP_EXPORT void on_tilp_button7_clicked(GtkButton* button, gpointer user_data)
 		dst_filename2 = g_strconcat(dst_filename, ".tig", NULL);
 	else
 		dst_filename2 = g_strdup(dst_filename);
-	g_free((void *)dst_filename);
+	//g_free((void *)dst_filename);
 
 	if (dst_filename2)
 	{
@@ -598,7 +599,7 @@ TILP_EXPORT void on_tilp_button7_clicked(GtkButton* button, gpointer user_data)
 	labels_refresh();
 }
 
-// Send TiGroup
+// Send TIGroup
 TILP_EXPORT void on_tilp_button8_clicked(GtkButton* button, gpointer user_data)
 {
 	const char *filename;
@@ -609,25 +610,9 @@ TILP_EXPORT void on_tilp_button8_clicked(GtkButton* button, gpointer user_data)
 	if(ret != BUTTON1)
 		return;
 
-#if 1
 	filename = create_fsel(local.cwdir, NULL, "*.tig", FALSE);
 	if(filename)
 		tilp_calc_send_tigroup(filename, mode);
-#else
-	if(local.selection2 == NULL)
-		return;
-	if(g_list_length(local.selection) > 1)
-		return;
-	
-	{
-		FileEntry *f = (FileEntry *) local.selection->data;
-
-		if(!tifiles_file_is_tigroup(f->name))
-			return;
-	
-		tilp_calc_send_tigroup(f->name, mode);
-	}
-#endif
 
 	return;
 }
@@ -721,7 +706,6 @@ TILP_EXPORT void on_tilp_menuitem12_clicked(GtkButton* button, gpointer user_dat
 	tilp_calc_get_infos(&infos);
 }
 
-
 //update View menu
 TILP_EXPORT void on_tilp_viewmenu_active(GtkButton* button, gpointer user_data)
 {
