@@ -56,7 +56,7 @@ void tilp_cmdline_version(void)
 #endif
 	printf(_("THIS PROGRAM COMES WITH ABSOLUTELY NO WARRANTY\n"));
 	printf(_("PLEASE READ THE DOCUMENTATION FOR DETAILS\n"));
-	printf(_("built on %s %s\n"), __DATE__, __TIME__);
+	//printf(_("built on %s %s\n"), __DATE__, __TIME__);
 	fflush(stdout);
 }
 
@@ -115,13 +115,13 @@ int tilp_cmdline_scan(int *argc, char ***argv)
 			{
 				for(i = 0; i < CABLE_MAX; i++)
 				{
-					if(!g_strcasecmp(ticables_model_to_string(i), *p))
+					if(!g_ascii_strcasecmp(ticables_model_to_string(i), *p))
 						options.cable_model = i;
 				}
 
 				for(i = 0; i < CALC_MAX; i++)
 				{
-					if(!g_strcasecmp(ticalcs_model_to_string(i), *p))
+					if(!g_ascii_strcasecmp(ticalcs_model_to_string(i), *p))
 						options.calc_model = i;
 				}
 			}
@@ -129,7 +129,7 @@ int tilp_cmdline_scan(int *argc, char ***argv)
 	}
 
 	// remap for USB handhelds
-	options.calc_model = tilp_remap_to_usb(options.cable_model, options.calc_model);
+	options.calc_model = ticalcs_remap_model_to_usb(options.cable_model, options.calc_model);
 
 	if(!options.cable_port)
 	{
