@@ -19,8 +19,8 @@
  *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#ifndef __TILP_CONFIG__
-#define __TILP_CONFIG__
+#ifndef __TILP_CONFIG_H__
+#define __TILP_CONFIG_H__
 
 int tilp_config_default(void);
 
