@@ -19,11 +19,8 @@
  *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#ifndef __TILP_PROBE__
-#define __TILP_PROBE__
-
-CalcModel tilp_remap_from_usb(CableModel cable, CalcModel calc);
-CalcModel tilp_remap_to_usb(CableModel cable, CalcModel calc);
+#ifndef __TILP_DEVICE_H__
+#define __TILP_DEVICE_H__
 
 int tilp_device_probe_usb(CableModel* cable, CablePort* port, CalcModel* calc);
 int tilp_device_probe_all(int ***result);
